@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2004-2007 Bastian Kleineidam
+# Copyright (C) 2004-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 """docutils HTML writer with navigation placeholder and information"""
 
-from docutils import writers, nodes, languages, utils
+from docutils import writers, nodes, utils
 from docutils.writers import html4css1
 from docutils.parsers.rst.directives.html import MetaBody
 
@@ -24,7 +24,7 @@ import sys
 import os
 import re
 try:
-    import Image                        # check for the Python Imaging Library
+    import Image # check for the Python Imaging Library
 except ImportError:
     Image = None
 
