@@ -3,7 +3,30 @@
  *
  *  Copyright (C) 1991, 1992  Linus Torvalds
  */
-#include <string.h>
+#include "Python.h"
+
+#ifndef Py_MEMCPY
+/* Py_MEMCPY can be used instead of memcpy in cases where the copied blocks
+ * are often very short.  While most platforms have highly optimized code for
+ * large transfers, the setup costs for memcpy are often quite high.  MEMCPY
+ * solves this by doing short copies "in line".
+ */
+
+#if defined(_MSC_VER)
+#define Py_MEMCPY(target, source, length) do {				\
+		size_t i_, n_ = (length);				\
+		char *t_ = (void*) (target);				\
+		const char *s_ = (void*) (source);			\
+		if (n_ >= 16)						\
+			memcpy(t_, s_, n_);				\
+		else							\
+			for (i_ = 0; i_ < n_; i_++)			\
+				t_[i_] = s_[i_];			\
+	} while (0)
+#else
+#define Py_MEMCPY memcpy
+#endif
+#endif
 
 #if !defined(HAVE_STRLCPY)
 /**
@@ -22,7 +45,7 @@ size_t strlcpy (char *dst, const char *src, size_t size)
     size_t ret = strlen(src);
     if (size > 0) {
         size_t len = (ret >= size) ? size-1 : ret;
-        memcpy(dst, src, len);
+        Py_MEMCPY(dst, src, len);
         dst[len] = '\0';
     }
     return ret;
@@ -45,7 +68,7 @@ size_t strlcat (char *dst, const char *src, size_t size)
     size -= dsize;
     if (len >= size)
         len = size-1;
-    memcpy(dst, src, len);
+    Py_MEMCPY(dst, src, len);
     dst[len] = '\0';
     return res;
 }
