@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2007 Bastian Kleineidam
+# Copyright (C) 2000-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@ Main functions for link checking.
 
 import os
 import cgi
+import logging
 import urllib
 import linkcheck.httplib2
 import linkcheck.dns.exception
@@ -139,3 +140,19 @@ def get_index_html (urls):
         lines.append('<a href="%s">%s</a>' % (url, name))
     lines.extend(["</body>", "</html>"])
     return os.linesep.join(lines)
+
+
+
+class StoringHandler (logging.Handler):
+    """Store all emitted log messages in a size-limited list.
+    Used by the CSS syntax checker."""
+
+    def __init__ (self, maxrecords=100):
+        logging.Handler.__init__(self)
+        self.storage = []
+        self.maxrecords = maxrecords
+
+    def emit (self, record):
+        if len(self.storage) >= self.maxrecords:
+            self.storage.pop()
+        self.storage.append(record)
