@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2007 Bastian Kleineidam
+# Copyright (C) 2000-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ import proxysupport
 import httpurl
 import internpaturl
 import linkcheck.ftpparse._ftpparse as ftpparse
-from const import WARN_FTP_MISSING_SLASH
+from const import WARN_FTP_MISSING_SLASH, PARSE_EXTENSIONS
 
 DEFAULT_TIMEOUT_SECS = 300
 
@@ -180,9 +180,13 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         """
         See if URL target is a HTML file by looking at the extension.
         """
-        if linkcheck.checker.const.extensions['html'].search(self.url):
-            return True
-        return False
+        return bool(PARSE_EXTENSIONS['html'].search(self.url))
+
+    def is_css (self):
+        """
+        See if URL target is a CSS file by looking at the extension.
+        """
+        return bool(PARSE_EXTENSIONS['css'].search(self.url))
 
     def is_parseable (self):
         """
@@ -190,7 +194,7 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         """
         if self.is_directory():
             return True
-        for ro in linkcheck.checker.const.extensions.itervalues():
+        for ro in PARSE_EXTENSIONS.itervalues():
             if ro.search(self.url):
                 return True
         return False
@@ -208,7 +212,7 @@ class FtpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         if self.is_directory():
             self.parse_html()
             return
-        for key, ro in linkcheck.checker.const.extensions.iteritems():
+        for key, ro in PARSE_EXTENSIONS.iteritems():
             if ro.search(self.url):
                 getattr(self, "parse_"+key)()
 
