@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2007 Bastian Kleineidam
+# Copyright (C) 2000-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,18 +28,19 @@ import cStringIO as StringIO
 import Cookie
 
 import linkcheck.url
-import linkcheck.gzip2
 import linkcheck.strformat
 import linkcheck.robotparser2
 import linkcheck.httplib2
 import httpheaders as headers
 import internpaturl
 import proxysupport
+from linkcheck import gzip2 as gzip
 # import warnings
 from const import WARN_HTTP_ROBOTS_DENIED, WARN_HTTP_NO_ANCHOR_SUPPORT, \
     WARN_HTTP_WRONG_REDIRECT, WARN_HTTP_MOVED_PERMANENT, \
     WARN_HTTP_EMPTY_CONTENT, WARN_HTTP_COOKIE_STORE_ERROR, \
-    WARN_HTTP_DECOMPRESS_ERROR, WARN_HTTP_UNSUPPORTED_ENCODING
+    WARN_HTTP_DECOMPRESS_ERROR, WARN_HTTP_UNSUPPORTED_ENCODING, \
+    PARSE_MIMETYPES
 
 # helper alias
 unicode_safe = linkcheck.strformat.unicode_safe
@@ -181,7 +182,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             self.method = "HEAD"
         # check the http connection
         response = self.check_http_connection()
-        if self.headers and self.headers.has_key("Server"):
+        if self.headers and "Server" in self.headers:
             server = self.headers['Server']
         else:
             server = _("unknown")
@@ -195,6 +196,10 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         # redirections might have changed the URL
         newurl = urlparse.urlunsplit(self.urlparts)
         if self.url != newurl:
+            if self.warn_redirect:
+                linkcheck.log.warn(linkcheck.LOG_CHECK,
+                    _("""URL %s has been redirected.
+Use URL %s instead for checking."""), self.url, newurl)
             self.url = newurl
         # check response
         if response:
@@ -323,6 +328,8 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             self.add_info(_("Redirected to %(url)s.") % {'url': newurl})
             # norm base url - can raise UnicodeError from url.idna_encode()
             redirected, is_idn = linkcheck.checker.urlbase.url_norm(newurl)
+            if is_idn:
+                pass # XXX warn about idn use
             assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
                 "Norm redirected to %r", redirected)
             urlparts = linkcheck.strformat.url_unicode_split(redirected)
@@ -501,9 +508,16 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         self.headers = response.msg
         self.persistent = not response.will_close
         if self.persistent and (self.method == "GET" or
-           self.headers.getheader("Content-Length", "")):
+           self.headers.getheader("Content-Length") != "0"):
             # always read content from persistent connections
             self._read_content(response)
+        if self.persistent and self.method == "HEAD":
+            # Some servers send page content after a HEAD request,
+            # but only after making the *next* request. This breaks
+            # protocol synchronisation. Workaround here is to close
+            # the connection after HEAD.
+            # Example: http://www.empleo.gob.mx (Apache/1.3.33 (Unix) mod_jk)
+            self.persistent = False
         # If possible, use official W3C HTTP response name
         if response.status in httpresponses:
             response.reason = httpresponses[response.status]
@@ -551,8 +565,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         if self.data is None:
             self.method = "GET"
             response = self._get_http_response()
-            tries, response = self.follow_redirections(response,
-                                                       set_result=False)
+            response = self.follow_redirections(response, set_result=False)[1]
             self.headers = response.msg
             self._read_content(response)
             if self.data is None:
@@ -568,8 +581,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
                 if encoding == 'deflate':
                     f = StringIO.StringIO(zlib.decompress(data))
                 else:
-                    f = linkcheck.gzip2.GzipFile('', 'rb', 9,
-                                      StringIO.StringIO(data))
+                    f = gzip.GzipFile('', 'rb', 9, StringIO.StringIO(data))
             except zlib.error, msg:
                 self.add_warning(_("Decompress error %(err)s") %
                                  {"err": str(msg)},
@@ -581,6 +593,16 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             self.data = data
             self.dltime = time.time() - t
 
+    def encoding_supported (self):
+        """Check if page encoding is supported."""
+        encoding = headers.get_content_encoding(self.headers)
+        if encoding and encoding not in _supported_encodings and \
+           encoding != 'identity':
+            self.add_warning(_('Unsupported content encoding %r.') % encoding,
+                             tag=WARN_HTTP_UNSUPPORTED_ENCODING)
+            return False
+        return True
+
     def is_html (self):
         """
         See if this URL points to a HTML file by looking at the
@@ -593,13 +615,15 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             return False
         if headers.get_content_type(self.headers) != "text/html":
             return False
-        encoding = headers.get_content_encoding(self.headers)
-        if encoding and encoding not in _supported_encodings and \
-           encoding != 'identity':
-            self.add_warning(_('Unsupported content encoding %r.') % encoding,
-                             tag=WARN_HTTP_UNSUPPORTED_ENCODING)
+        return self.encoding_supported()
+
+    def is_css (self):
+        """Return True iff content of this url is CSS stylesheet."""
+        if not (self.valid and self.headers):
             return False
-        return True
+        if headers.get_content_type(self.headers) != "text/css":
+            return False
+        return self.encoding_supported()
 
     def is_http (self):
         """
@@ -619,8 +643,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         """
         if not (self.valid and self.headers):
             return False
-        if headers.get_content_type(self.headers) not in \
-           ("text/html", "text/css"):
+        if headers.get_content_type(self.headers) not in PARSE_MIMETYPES:
             return False
         encoding = headers.get_content_encoding(self.headers)
         if encoding and encoding not in _supported_encodings and \
@@ -634,11 +657,13 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         """
         Parse file contents for new links to check.
         """
-        ptype = headers.get_content_type(self.headers)
-        if ptype == "text/html":
+        ctype = headers.get_content_type(self.headers)
+        if ctype == "text/html":
             self.parse_html()
-        elif ptype == "text/css":
+        elif ctype == "text/css":
             self.parse_css()
+        elif ctype == "application/x-shockwave-flash":
+            self.parse_swf()
 
     def get_robots_txt_url (self):
         """
