@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2007 Bastian Kleineidam
+# Copyright (C) 2000-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@ import email.Utils
 
 import urlbase
 import linkcheck.log
+import linkcheck.strformat
 import linkcheck.dns.resolver
 from const import WARN_MAIL_NO_ADDRESSES, WARN_MAIL_NO_MX_HOST, \
     WARN_MAIL_UNVERIFIED_ADDRESS, WARN_MAIL_NO_CONNECTION
@@ -65,7 +66,7 @@ class MailtoUrl (urlbase.UrlBase):
         self.headers = {}
         self.addresses = email.Utils.getaddresses([self.cutout_addresses()])
         for key in ("to", "cc", "bcc"):
-            if self.headers.has_key(key):
+            if key in self.headers:
                 for val in self.headers[key]:
                     a = urllib.unquote(val)
                     self.addresses.extend(email.Utils.getaddresses([a]))
@@ -151,10 +152,14 @@ class MailtoUrl (urlbase.UrlBase):
             "checking mail address %r", mail)
         assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
             "splitting address")
+        mail = linkcheck.strformat.ascii_safe(mail)
         username, domain = _split_address(mail)
         assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
             "looking up MX mailhost %r", domain)
-        answers = linkcheck.dns.resolver.query(domain, 'MX')
+        try:
+            answers = linkcheck.dns.resolver.query(domain, 'MX')
+        except linkcheck.dns.resolver.NoAnswer:
+            answers = []
         if len(answers) == 0:
             self.add_warning(_("No MX mail host for %(domain)s found.") %
                             {'domain': domain},
