@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2004-2007 Bastian Kleineidam
+# Copyright (C) 2004-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@ import unittest
 
 import linkcheck.checker
 import linkcheck.configuration
+import linkcheck.director
 import linkcheck.logger
 
 # helper alias
@@ -190,7 +191,6 @@ class LinkCheckTest (unittest.TestCase):
         logargs = {'expected': self.get_resultlines(filename)}
         aggregate = get_test_aggregate(confargs, logargs)
         url_data = get_url_from(url, 0, aggregate)
-        # XXX if assume_local
         linkcheck.add_intern_pattern(url_data, aggregate.config)
         aggregate.urlqueue.put(url_data)
         linkcheck.director.check_urls(aggregate)
@@ -216,7 +216,6 @@ class LinkCheckTest (unittest.TestCase):
             logargs['parts'] = parts
         aggregate = get_test_aggregate(confargs, logargs)
         url_data = get_url_from(url, 0, aggregate)
-        # XXX if assume_local:
         linkcheck.add_intern_pattern(url_data, aggregate.config)
         aggregate.urlqueue.put(url_data)
         linkcheck.director.check_urls(aggregate)
