@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2004-2007 Bastian Kleineidam
+# Copyright (C) 2004-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@ class TestHttp (httptest.HttpServerTest):
             self.robots_txt_test()
             self.robots_txt2_test()
             self.noproxyfor_test()
+            self.swf_test()
         finally:
             self.stop_server()
 
@@ -129,7 +130,7 @@ class TestHttp (httptest.HttpServerTest):
         """
         Test setting proxy and --no-proxy-for option.
         """
-        os.environ["http_proxy"] = "http://imadoofus:8877"
+        os.environ["http_proxy"] = "http://example.org:8877"
         confargs = {"noproxyfor": [re.compile("localhost")]}
         url = u"http://localhost:%d/linkcheck/checker/tests/data/http.html" % \
               self.port
@@ -138,13 +139,29 @@ class TestHttp (httptest.HttpServerTest):
             u"url %s" % url,
             u"cache key %s" % nurl,
             u"real url %s" % nurl,
-            u"info Ignoring proxy setting 'imadoofus:8877'",
+            u"info Ignoring proxy setting 'example.org:8877'",
             u"valid",
         ]
         self.direct(url, resultlines, recursionlevel=0,
                     confargs=confargs)
         del os.environ["http_proxy"]
 
+    def swf_test (self):
+        url = u"http://localhost:%d/linkcheck/checker/tests/data/" \
+              u"test.swf" % self.port
+        resultlines = [
+            u"url %s" % url,
+            u"cache key %s" % url,
+            u"real url %s" % url,
+            u"valid",
+            u"url http://www.example.org/",
+            u"cache key http://www.example.org/",
+            u"real url http://www.example.org/",
+            u"warning Access denied by robots.txt, checked only syntax.",
+            u"valid",
+        ]
+        self.direct(url, resultlines, recursionlevel=1)
+
 
 def get_cookie (maxage=2000):
     data = (
