@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2007 Bastian Kleineidam
+# Copyright (C) 2000-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@ Base URL handler.
 
 import sys
 import os
+import logging
 import urlparse
 import urllib2
 import urllib
@@ -116,6 +117,8 @@ class UrlBase (object):
         url = linkcheck.checker.absolute_url(base_url, base_ref, parent_url)
         # assume file link if no scheme is found
         self.scheme = url.split(":", 1)[0] or "file"
+        # warn if URL is redirected (for commandline client)
+        self.warn_redirect = False
 
     def reset (self):
         """
@@ -189,6 +192,10 @@ class UrlBase (object):
         """
         return False
 
+    def is_css (self):
+        """Return True iff content of this url is CSS stylesheet."""
+        return False
+
     def is_http (self):
         """
         Return True for http:// URLs.
@@ -424,7 +431,12 @@ class UrlBase (object):
             except tuple(linkcheck.checker.const.ExcList):
                 value = self.handle_exception()
                 self.set_result(unicode_safe(value), valid=False)
-
+        # check HTML/CSS syntax
+        if self.valid:
+            if self.is_html() and self.aggregate.config["checkhtml"]:
+                self.check_html()
+            if self.is_css() and self.aggregate.config["checkcss"]:
+                self.check_css()
         self.checktime = time.time() - check_start
         # check recursion
         try:
@@ -464,7 +476,12 @@ class UrlBase (object):
             not value:
             # EBADF occurs when operating on an already socket
             self.caching = False
-        return value
+        errmsg = etype.__name__
+        if str(value):
+            # use Exception class name
+            errmsg += ": %s" % str(value)
+        # limit length to 240
+        return linkcheck.strformat.limit(errmsg, length=240)
 
     def check_connection (self):
         """
@@ -627,6 +644,57 @@ class UrlBase (object):
                          "maxbytes": linkcheck.strformat.strsize(maxbytes)},
                           tag=WARN_URL_CONTENT_TOO_LARGE)
 
+    def check_html (self):
+        """Check HTML syntax of this page (which is supposed to be HTML)."""
+        try:
+            import tidy
+        except ImportError:
+            linkcheck.log.warn(linkcheck.LOG_CHECK,
+                _("warning: tidy module is not available; " \
+                 "download from http://utidylib.berlios.de/"))
+            return
+        options = dict(output_html=0, show_warnings=1, quiet=True,
+            input_encoding='utf8', output_encoding='utf8', tidy_mark=0)
+        try:
+            doc = tidy.parseString(self.get_content(), **options)
+            errors = filter_tidy_errors(doc.errors)
+            for err in errors:
+                self.add_warning("HTMLTidy: %s" % err)
+        except:
+            # catch _all_ exceptions since we dont want third party module
+            # errors to propagate into this library
+            err = str(sys.exc_info()[1])
+            linkcheck.log.warn(linkcheck.LOG_CHECK,
+                _("warning: tidy HTML parsing caused error: %s ") % err)
+
+    def check_css (self):
+        """Check CSS syntax of this page (which is supposed to be CSS)."""
+        try:
+            import cssutils
+        except ImportError:
+            linkcheck.log.warn(linkcheck.LOG_CHECK,
+                _("warning: cssutils module is not available; " \
+                 "download from http://cthedot.de/cssutils/"))
+            return
+        try:
+            log = logging.getLogger('cssutils')
+            log.propagate = 0
+            del log.handlers[:]
+            handler = linkcheck.checker.StoringHandler()
+            log.addHandler(handler)
+            log.setLevel(logging.WARN)
+            cssparser = cssutils.CSSParser(log=log)
+            cssparser.parseString(self.get_content(), href=self.url)
+            for record in handler.storage:
+                self.add_warning("cssutils: %s" % record.getMessage())
+        except:
+            raise
+            # catch _all_ exceptions since we dont want third party module
+            # errors to propagate into this library
+            err = str(sys.exc_info()[1])
+            linkcheck.log.warn(linkcheck.LOG_CHECK,
+                _("warning: cssutils parsing caused error: %s ") % err)
+
     def parse_url (self):
         """
         Parse url content and search for recursive links.
@@ -731,6 +799,16 @@ class UrlBase (object):
                              parent_url=self.url, line=lineno, column=column)
                 self.aggregate.urlqueue.put(url_data)
 
+    def parse_swf (self):
+        """Parse a SWF file for URLs."""
+        linkfinder = linkcheck.linkparse.swf_url_re.finditer
+        for mo in linkfinder(self.get_content()):
+            url = mo.group()
+            url_data = linkcheck.checker.get_url_from(url,
+                         self.recursion_level+1, self.aggregate,
+                         parent_url=self.url)
+            self.aggregate.urlqueue.put(url_data)
+
     def serialized (self):
         """
         Return serialized url check data as unicode string.
@@ -783,3 +861,8 @@ class UrlBase (object):
         """
         return u"<%s >" % self.serialized()
 
+
+def filter_tidy_errors (errors):
+    """Filter certain errors from HTML tidy run."""
+    return [x for x in errors if not \
+        (x.severity=='W' and x.message=='<table> lacks "summary" attribute')]
