@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2007 Bastian Kleineidam
+# Copyright (C) 2000-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,8 +32,8 @@ AppName = u"LinkChecker"
 App = AppName+u" "+Version
 Author =  _linkchecker_configdata.author
 HtmlAuthor = Author.replace(u' ', u'&nbsp;')
-Copyright = u"Copyright (C) 2000-2007 "+Author
-HtmlCopyright = u"Copyright &copy; 2000-2007 "+HtmlAuthor
+Copyright = u"Copyright (C) 2000-2008 "+Author
+HtmlCopyright = u"Copyright &copy; 2000-2008 "+HtmlAuthor
 AppInfo = App+u"              "+Copyright
 HtmlAppInfo = App+u", "+HtmlCopyright
 Url = _linkchecker_configdata.url
@@ -145,6 +145,8 @@ class Configuration (dict):
         self["threads"] = 10
         # socket timeout in seconds
         self["timeout"] = 60
+        self["checkhtml"] = False
+        self["checkcss"] = False
 
     def init_logging (self, debug=None):
         """
