@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2004-2007 Bastian Kleineidam
+# Copyright (C) 2004-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -68,13 +68,13 @@ class ListDict (dict):
         self._keys = []
 
     def setdefault (self, key, *args):
-        if not self.has_key(key):
+        if key not in self:
             self._keys.append(key)
         return super(ListDict, self).setdefault(key, *args)
 
     def __setitem__ (self, key, value):
         """Add key,value to dict, append key to sorted list."""
-        if not self.has_key(key):
+        if key not in self:
             self._keys.append(key)
         super(ListDict, self).__setitem__(key, value)
 
