@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2005-2007 Bastian Kleineidam
+# Copyright (C) 2005-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -360,7 +360,7 @@ def from_headers (strheader):
     """
     fp = StringIO.StringIO(strheader)
     headers = rfc822.Message(fp, seekable=True)
-    if not headers.has_key("Host"):
+    if "Host" not in headers:
         raise ValueError("Required header 'Host:' missing")
     host = headers["Host"]
     scheme = headers.get("Scheme", "http")
