@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2006-2007 Bastian Kleineidam
+# Copyright (C) 2006-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -74,6 +74,8 @@ def interrupt (aggregate):
         try:
             linkcheck.log.warn(linkcheck.LOG_CHECK,
                _("keyboard interrupt; waiting for active threads to finish"))
+            linkcheck.log.warn(linkcheck.LOG_CHECK,
+               _("another keyboard interrupt will exit immediately"))
             print_active_threads(aggregate)
             abort(aggregate)
             break
@@ -100,8 +102,20 @@ def abort (aggregate):
             aggregate.logger.end_log_output()
             break
         except KeyboardInterrupt:
-            linkcheck.log.warn(linkcheck.LOG_CHECK, _("shutdown in progress"))
-            print_active_threads(aggregate)
+            linkcheck.log.warn(linkcheck.LOG_CHECK, _("keyboard interrupt; force shutdown"))
+            force_shutdown()
+
+
+def force_shutdown ():
+    """Force shutdown, not finishing anything."""
+    import os
+    if os.name == "posix":
+        # POSIX systems seem to do fine with sys.exit()
+        import sys
+        sys.exit(1)
+    else:
+        # forced exit without cleanup
+        os._exit(1)
 
 
 def get_aggregate (config):
