@@ -151,7 +151,7 @@ class Message(object):
         self.first = True
 
     def __repr__(self):
-        return '<DNS message, ID ' + `self.id` + '>'
+        return '<DNS message, ID %r>' % self.id
 
     def __str__(self):
         return self.to_text()
@@ -245,9 +245,6 @@ class Message(object):
     def is_response(self, other):
         """Is other a response to self?
         @rtype: bool"""
-        if self.id != other.id:
-            linkcheck.log.warn(linkcheck.LOG_DNS,
-                "DNS message IDs differ\n%s\n----\n%s\n----", self, other)
         if other.flags & linkcheck.dns.flags.QR == 0 or \
            linkcheck.dns.opcode.from_flags(self.flags) != \
            linkcheck.dns.opcode.from_flags(other.flags):
@@ -743,16 +740,16 @@ class _TextReader(object):
         name = self.last_name
         token = self.tok.get()
         if token[0] != linkcheck.dns.tokenizer.IDENTIFIER:
-            raise linkcheck.dns.exception.SyntaxError
+            raise linkcheck.dns.exception.DNSSyntaxError
         # Class
         try:
             rdclass = linkcheck.dns.rdataclass.from_text(token[1])
             token = self.tok.get()
             if token[0] != linkcheck.dns.tokenizer.IDENTIFIER:
-                raise linkcheck.dns.exception.SyntaxError
-        except linkcheck.dns.exception.SyntaxError:
-            raise linkcheck.dns.exception.SyntaxError
-        except:
+                raise linkcheck.dns.exception.DNSSyntaxError
+        except linkcheck.dns.exception.DNSSyntaxError:
+            raise linkcheck.dns.exception.DNSSyntaxError
+        except StandardError:
             rdclass = linkcheck.dns.rdataclass.IN
         # Type
         rdtype = linkcheck.dns.rdatatype.from_text(token[1])
@@ -775,29 +772,29 @@ class _TextReader(object):
         name = self.last_name
         token = self.tok.get()
         if token[0] != linkcheck.dns.tokenizer.IDENTIFIER:
-            raise linkcheck.dns.exception.SyntaxError
+            raise linkcheck.dns.exception.DNSSyntaxError
         # TTL
         try:
             ttl = int(token[1], 0)
             token = self.tok.get()
             if token[0] != linkcheck.dns.tokenizer.IDENTIFIER:
-                raise linkcheck.dns.exception.SyntaxError
-        except linkcheck.dns.exception.SyntaxError:
-            raise linkcheck.dns.exception.SyntaxError
-        except:
+                raise linkcheck.dns.exception.DNSSyntaxError
+        except linkcheck.dns.exception.DNSSyntaxError:
+            raise linkcheck.dns.exception.DNSSyntaxError
+        except StandardError:
             ttl = 0
         # Class
         try:
             rdclass = linkcheck.dns.rdataclass.from_text(token[1])
             token = self.tok.get()
             if token[0] != linkcheck.dns.tokenizer.IDENTIFIER:
-                raise linkcheck.dns.exception.SyntaxError
+                raise linkcheck.dns.exception.DNSSyntaxError
             if rdclass == linkcheck.dns.rdataclass.ANY or rdclass == linkcheck.dns.rdataclass.NONE:
                 deleting = rdclass
                 rdclass = self.zone_rdclass
-        except linkcheck.dns.exception.SyntaxError:
-            raise linkcheck.dns.exception.SyntaxError
-        except:
+        except linkcheck.dns.exception.DNSSyntaxError:
+            raise linkcheck.dns.exception.DNSSyntaxError
+        except StandardError:
             rdclass = linkcheck.dns.rdataclass.IN
         # Type
         rdtype = linkcheck.dns.rdatatype.from_text(token[1])
@@ -852,7 +849,7 @@ def from_text(text):
     @param text: The text format message.
     @type text: string
     @raises UnknownHeaderField:
-    @raises linkcheck.dns.exception.SyntaxError:
+    @raises linkcheck.dns.exception.DNSSyntaxError:
     @rtype: linkcheck.dns.message.Message object"""
 
     # 'text' can also be a file, but we don't publish that fact
@@ -870,7 +867,7 @@ def from_file(f):
     @param f: file or string.  If I{f} is a string, it is treated
     as the name of a file to open.
     @raises UnknownHeaderField:
-    @raises linkcheck.dns.exception.SyntaxError:
+    @raises linkcheck.dns.exception.DNSSyntaxError:
     @rtype: linkcheck.dns.message.Message object"""
     if sys.hexversion >= 0x02030000:
         # allow Unicode filenames; turn on universal newline support
