@@ -25,7 +25,6 @@ import sys
 import time
 import encodings.idna
 
-import linkcheck
 import linkcheck.log
 import linkcheck.dns.exception
 import linkcheck.dns.message
@@ -73,8 +72,11 @@ class Answer(object):
     Instances of this class bundle up the result of a successful DNS
     resolution.
 
-    For convenience, the answer is iterable.  "for a in answer" is
-    equivalent to "for a in answer.rrset".
+    For convenience, the answer object implements much of the sequence
+    protocol, forwarding to its rrset.  E.g. "for a in answer" is
+    equivalent to "for a in answer.rrset", "answer[i]" is equivalent
+    to "answer.rrset[i]", and "answer[i:j]" is equivalent to
+    "answer.rrset[i:j]".
 
     Note that CNAMEs or DNAMEs in the response may mean that answer
     node's name might not be the query name.
@@ -150,6 +152,19 @@ class Answer(object):
     def __iter__(self):
         return iter(self.rrset)
 
+    def __getitem__(self, i):
+        return self.rrset[i]
+
+    def __delitem__(self, i):
+        del self.rrset[i]
+
+    def __getslice__(self, i, j):
+        return self.rrset[i:j]
+
+    def __delslice__(self, i, j):
+        del self.rrset[i:j]
+
+
 class Cache(object):
     """Simple DNS answer cache.
 
@@ -225,7 +240,7 @@ class Cache(object):
         @type key: (linkcheck.dns.name.Name, int, int) tuple or None
         """
         if not key is None:
-            if self.data.has_key(key):
+            if key in self.data:
                 del self.data[key]
         else:
             self.data = {}
@@ -595,7 +610,7 @@ class Resolver(object):
                     raise NoNameservers, \
                       "No DNS servers %s could answer the query %s" % \
                       (str(self.nameservers), str(qname))
-                for nameserver in nameservers:
+                for nameserver in nameservers[:]:
                     timeout = self._compute_timeout(start)
                     try:
                         if tcp:
@@ -639,6 +654,8 @@ class Resolver(object):
                         nameservers.remove(nameserver)
                     response = None
 
+                if response is not None:
+                    break
                 # All nameservers failed!
 
                 if len(nameservers) > 0:
