@@ -78,6 +78,30 @@ class TestResolver (unittest.TestCase):
         self.assert_(cache.get((name, linkcheck.dns.rdatatype.A,
                                 linkcheck.dns.rdataclass.IN)) is None)
 
+    def testZoneForName1(self):
+        name = linkcheck.dns.name.from_text('www.dnspython.org.')
+        ezname = linkcheck.dns.name.from_text('dnspython.org.')
+        zname = linkcheck.dns.resolver.zone_for_name(name)
+        self.failUnless(zname == ezname)
+
+    def testZoneForName2(self):
+        name = linkcheck.dns.name.from_text('a.b.www.dnspython.org.')
+        ezname = linkcheck.dns.name.from_text('dnspython.org.')
+        zname = linkcheck.dns.resolver.zone_for_name(name)
+        self.failUnless(zname == ezname)
+
+    def testZoneForName3(self):
+        name = linkcheck.dns.name.from_text('dnspython.org.')
+        ezname = linkcheck.dns.name.from_text('dnspython.org.')
+        zname = linkcheck.dns.resolver.zone_for_name(name)
+        self.failUnless(zname == ezname)
+
+    def testZoneForName4(self):
+        def bad():
+            name = linkcheck.dns.name.from_text('dnspython.org', None)
+            zname = linkcheck.dns.resolver.zone_for_name(name)
+        self.failUnlessRaises(linkcheck.dns.resolver.NotAbsolute, bad)
+
 
 def test_suite ():
     return unittest.makeSuite(TestResolver)
