@@ -224,7 +224,7 @@ def HandleManTypes (r, conn):
                 'FCGI_MAX_REQS'  : FCGI_MAX_REQS,
                 'FCGI_MPXS_CONNS': FCGI_MPXS_CONNS}
         for i in r.values.keys():
-            if _vars.has_key(i):
+            if i in _vars:
                 v[i] = _vars[i]
         r.values = _vars
         r.write_record(conn)
@@ -396,9 +396,8 @@ class FCGI (object):
             set_cgi_env(os.environ)
             self.env = os.environ
             self.stdin, self.out, self.err = sys.stdin, sys.stdout, sys.stderr
-            return
 
-        if os.environ.has_key('FCGI_WEB_SERVER_ADDRS'):
+        if 'FCGI_WEB_SERVER_ADDRS' in os.environ:
             addrs = os.environ['FCGI_WEB_SERVER_ADDRS'].split(',')
             good_addrs = [ addr.strip() for addr in addrs ]
         else:
@@ -406,7 +405,7 @@ class FCGI (object):
 
         self.conn, addr = _sock.accept()
         # Check if the connection is from a legal address
-        if good_addrs != None and addr not in good_addrs:
+        if good_addrs is not None and addr not in good_addrs:
             raise error, 'Connection from invalid server!'
 
         stdin = data = ""
@@ -495,7 +494,7 @@ class FCGI (object):
 
     def getFieldStorage (self):
         method = 'GET'
-        if self.env.has_key('REQUEST_METHOD'):
+        if 'REQUEST_METHOD' in self.env:
             method = self.env['REQUEST_METHOD'].upper()
         if method == 'GET':
             return cgi.FieldStorage(environ=self.env, keep_blank_values=1)
