@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2007 Bastian Kleineidam
+# Copyright (C) 2000-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@ import locale
 import gettext
 
 # more supported languages are added in init()
-supported_languages = ['en']
+supported_languages = set(['en'])
 default_language = 'en'
 default_encoding = locale.getpreferredencoding()
 # It can happen that the preferrec encoding is not determinable, which
@@ -77,16 +77,17 @@ def init (domain, directory):
     Initialize this gettext i18n module. Searches for supported languages
     and installs the gettext translator class.
     """
-    global default_language
+    global default_language, default_encoding
     if os.path.isdir(directory):
         # get supported languages
         for lang in os.listdir(directory):
             path = os.path.join(directory, lang, 'LC_MESSAGES')
             if os.path.exists(os.path.join(path, '%s.mo' % domain)):
-                supported_languages.append(lang)
-    loc = get_locale()
+                supported_languages.add(lang)
+    loc, encoding = get_locale()
     if loc in supported_languages:
         default_language = loc
+        default_encoding = encoding
     # install translation service routines into default namespace
     translator = get_translator(domain, directory,
                                 languages=[default_language], fallback=True)
@@ -120,7 +121,7 @@ def get_headers_lang (headers):
     """
     Return preferred supported language in given HTTP headers.
     """
-    if not headers.has_key('Accept-Language'):
+    if 'Accept-Language' not in headers:
         return default_language
     languages = headers['Accept-Language'].split(",")
     # sort with preference values
@@ -148,14 +149,15 @@ def get_locale ():
     Return current configured locale.
     """
     loc = None
+    encoding = 'ascii'
     try:
-        loc = locale.getdefaultlocale()[0]
+        loc, encoding = locale.getlocale(category=locale.LC_ALL)
     except ValueError:
         # XXX ignore Python bug
-        # http://sourceforge.net/tracker/index.php?func=detail&aid=1158909&group_id=5470&atid=105470
+        # http://bugs.python.org/issue1158909
         pass
     if loc is None:
-        return 'C'
+        return ('C', 'ascii')
     loc = locale.normalize(loc)
     # split up the locale into its base components
     pos = loc.find('@')
@@ -167,7 +169,7 @@ def get_locale ():
     pos = loc.find('_')
     if pos >= 0:
         loc = loc[:pos]
-    return loc
+    return (loc, encoding)
 
 
 lang_names = {
