@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2007 Bastian Kleineidam
+# Copyright (C) 2000-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@ Common CGI functions used by the CGI scripts.
 
 import sys
 import os
+import locale
 import re
 import time
 import urlparse
@@ -33,7 +34,13 @@ import linkcheck.checker
 import linkcheck.director
 
 _logfile = None
-_supported_langs = ('de', 'fr', 'nl', 'C')
+_supported_langs = ('de', 'C')
+# map language -> locale name
+lang_locale = {
+    'de': 'de_DE',
+    'C': 'C',
+    'en': 'en_EN',
+}
 _is_level = re.compile(r'^(0|1|2|3|-1)$').match
 
 class FormError (StandardError):
@@ -84,9 +91,9 @@ def checklink (out=sys.stdout, form=None, env=os.environ):
     config["recursionlevel"] = int(form["level"].value)
     config["logger"] = config.logger_new('html', fd=out)
     config["threads"] = 0
-    if form.has_key("anchors"):
+    if "anchors" in form:
         config["anchors"] = True
-    if not form.has_key("errors"):
+    if "errors" not in form:
         config["verbose"] = True
     # avoid checking of local files or other nasty stuff
     pat = "!^%s$" % linkcheck.url.safe_url_pattern
@@ -121,15 +128,15 @@ def checkform (form):
     only plain strings as exception text.
     """
     # check lang support
-    if form.has_key("language"):
+    if "language" in form:
         lang = form['language'].value
         if lang in _supported_langs:
-            os.environ['LC_MESSAGES'] = lang
+            locale.setlocale(locale.LC_ALL, lang_locale[lang])
             linkcheck.init_i18n()
         else:
             raise FormError(_("unsupported language"))
     # check url syntax
-    if form.has_key("url"):
+    if "url" in form:
         url = form["url"].value
         if not url or url == "http://":
             raise FormError(_("empty url was given"))
@@ -138,13 +145,13 @@ def checkform (form):
     else:
         raise FormError(_("no url was given"))
     # check recursion level
-    if form.has_key("level"):
+    if "level" in form:
         level = form["level"].value
         if not _is_level(level):
             raise FormError(_("invalid recursion level"))
     # check options
     for option in ("anchors", "errors", "intern"):
-        if form.has_key(option):
+        if option in form:
             if not form[option].value == "on":
                 raise FormError(_("invalid %s option syntax") % option)
 
@@ -158,12 +165,12 @@ def logit (form, env):
     elif type(_logfile) == types.StringType:
         _logfile = file(_logfile, "a")
     _logfile.write("\n"+linkcheck.strformat.strtime(time.time())+"\n")
-    for var in ["HTTP_USER_AGENT", "REMOTE_ADDR",
-                "REMOTE_HOST", "REMOTE_PORT"]:
-        if env.has_key(var):
+    for var in ("HTTP_USER_AGENT", "REMOTE_ADDR",
+                "REMOTE_HOST", "REMOTE_PORT"):
+        if var in env:
             _logfile.write(var+"="+env[var]+"\n")
-    for key in ["level", "url", "anchors", "errors", "intern", "language"]:
-        if form.has_key(key):
+    for key in ("level", "url", "anchors", "errors", "intern", "language"):
+        if key in form:
             _logfile.write(str(form[key])+"\n")
 
 
