@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2001-2007 Bastian Kleineidam
+# Copyright (C) 2001-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@ import re
 import linkcheck.strformat
 import linkcheck.linkname
 import linkcheck.log
+import linkcheck.url
 
 MAX_NAMELEN = 256
 unquote = linkcheck.strformat.unquote
@@ -50,7 +51,7 @@ LinkTags = {
     'meta':     [u'content', u'href'],
     'object':   [u'classid', u'data', u'archive', u'usemap'],
     'q':        [u'cite'],
-    'script':   [u'src', u'for'],
+    'script':   [u'src'],
     'table':    [u'background'],
     'td':       [u'background'],
     'th':       [u'background'],
@@ -63,6 +64,7 @@ LinkTags = {
 refresh_re = re.compile(ur"(?i)^\d+;\s*url=(?P<url>.+)$")
 _quoted_pat = ur"('[^']+'|\"[^\"]+\"|[^\)\s]+)"
 css_url_re = re.compile(ur"url\(\s*(?P<url>%s)\s*\)" % _quoted_pat)
+swf_url_re = re.compile("(?i)%s" % linkcheck.url.safe_url_pattern)
 c_comment_re = re.compile(ur"/\*.*?\*/", re.DOTALL)
 
 def strip_c_comments (text):
