@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2007 Bastian Kleineidam
+# Copyright (C) 2000-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,8 +37,8 @@ HTML_HEADER = """<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
  "http://www.w3.org/TR/html4/loose.dtd">
 <html>
 <head>
-<meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1">
-<title>%s</title>
+<meta http-equiv="Content-Type" content="text/html; charset=%(encoding)s">
+<title>%(title)s</title>
 <style type="text/css">
 <!--
  h2 { font-family: Verdana,sans-serif; font-size: 22pt; font-weight: bold }
@@ -49,7 +49,7 @@ HTML_HEADER = """<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
 -->
 </style>
 </head>
-<body bgcolor="%s" link="%s" vlink="%s" alink="%s">
+<body bgcolor="%(body)s" link="%(link)s" vlink="%(vlink)s" alink="%(alink)s">
 """
 
 class HtmlLogger (linkcheck.logger.Logger):
@@ -86,14 +86,18 @@ class HtmlLogger (linkcheck.logger.Logger):
         self.write(u" -->")
 
     def start_output (self):
-        """
-        Write start of checking info.
-        """
+        """Write start of checking info."""
         super(HtmlLogger, self).start_output()
         self.starttime = time.time()
-        self.write(HTML_HEADER % (linkcheck.configuration.App,
-                   self.colorbackground,
-                   self.colorlink, self.colorlink, self.colorlink))
+        header = {
+            "encoding": self.output_encoding,
+            "title": linkcheck.configuration.App,
+            "body": self.colorbackground,
+            "link": self.colorlink,
+            "vlink": self.colorlink,
+            "alink": self.colorlink,
+        }
+        self.write(HTML_HEADER % header)
         self.comment("Generated by %s" % linkcheck.configuration.App)
         if self.has_part('intro'):
             self.write(u"<center><h2>"+linkcheck.configuration.App+
