@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2007 Bastian Kleineidam
+# Copyright (C) 2000-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,12 +29,12 @@ import time
 import socket
 import re
 import zlib
-import gzip
 import sys
 import cStringIO as StringIO
 import linkcheck
 import configuration
 import log
+from linkcheck import gzip2 as gzip
 
 __all__ = ["RobotFileParser"]
 
