@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2004-2007 Bastian Kleineidam
+# Copyright (C) 2004-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -213,10 +213,13 @@ class TestCaselessDict (unittest.TestCase):
         self.d.clear()
         self.assert_(not self.d)
 
-    def test_has_key (self):
+    def test_containment (self):
         self.assert_(not self.d)
+        self.assert_("A" not in self.d)
+        self.assert_("a" not in self.d)
         self.d["a"] = 5
-        self.assert_(self.d.has_key("A"))
+        self.assert_("A" in self.d)
+        self.assert_("a" in self.d)
 
     def test_setdefault (self):
         self.assert_(not self.d)
@@ -230,7 +233,7 @@ class TestCaselessDict (unittest.TestCase):
         self.assertEquals(self.d.get("A"), 42)
         self.assert_(self.d.get("B") is None)
 
-    def test_update (self):
+    def test_update2 (self):
         self.assert_(not self.d)
         self.d["a"] = 42
         self.d.update({"A": 43})
@@ -281,6 +284,7 @@ class TestCaselessSortedDict (unittest.TestCase):
         prev = None
         for key, value in self.d.items():
             self.assert_(key > prev)
+            self.assertEqual(value, self.d[key])
             prev = key
 
 
