@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2005-2007 Bastian Kleineidam
+# Copyright (C) 2005-2008 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -79,7 +79,7 @@ class TestLinkparser (unittest.TestCase):
 
     def test_comment_stripping (self):
         strip = linkcheck.linkparse.strip_c_comments
-        content = "/* url('http://imadoofus.org')*/"
+        content = "/* url('http://example.org')*/"
         self.assertEqual(strip(content), "")
         content = "/* * * **/"
         self.assertEqual(strip(content), "")
